---
layout: thing
thing: 8
title: 'DOIs and citation metrics for data'
short_title: Metrics
description: |
    What are Digital Object Identifiers (DOIs) and how do they support data
    citation and metrics for data and related research objects?
overview:
 Getting started: what are DOIs and why are they critical for accurate citation metrics?
 Learn more: delve into altmetrics (and donuts!)
 Challenge me: what about minting DOIs for software, algorithms and grey literature?
category: Data citation & impact
---

## Getting started
### DOIs, data citation and metrics

Digital Object Identifiers (DOIs) are unique identifiers that provide
persistent access to published articles, datasets, software versions and
a range of other research inputs and outputs. There are over [190 million
DOIs in use](https://www.doi.org/factsheets/DOIKeyFacts.html).

Each DOI is unique but a typical DOI looks like this: <https://doi.org/10.4225/08/50F62E0D359D5>

DOIs can be used to collect citation metrics about the use of a dataset
or article.

1.  Start by watching this short  video [Persistent identifiers and data
    citation explained](https://www.youtube.com/watch?v=PgqtiY7oZ6k)
    (4.5 min) from Research Data Netherlands. It gives you a succinct,
    clear explanation of how DOIs underpin data citation.
2.  Have a look at the poster below (opens to an A4 size) - follow the
    arrows to see how DOIs are attached to data sets.
    
    [![data citation poster]({{ site.baseurl }}/images/data-citation-poster-thumbnail.png)](https://www.ands.org.au/__data/assets/pdf_file/0003/383025/data_citation_poster.pdf "data citation poster")
    
3.  This CSIRO data record shows how DOIs are used. Click on this DOI to
    ‘resolve’ the DOI and be taken to the record:
    <https://doi.org/10.4225/08/50F62E0D359D5>
    Click on both the Description and Files tabs and note how many times
    the DOI is used in this data record. It will give you some idea why
    DOIs are given such prominence.
4.  This [same
    record](https://researchdata.edu.au/time-series-plankton-loganaposs-dam/445000 "time series plankton record") has
    been syndicated to Research Data Australia. Click on the Cite icon
    on the upper left of the record (under the green button Access the
    Data). Then click on the DOI in the data citation. No matter where
    the DOI appears it always resolves back to its original dataset
    record to avoid duplication, i.e. many records, one copy.
5.  DOIs can also be applied to grey literature, such as reports like
    the Haefliger’s Cottage Investigation with this DOI
    <http://dx.doi.org/10.4227/11/50459F7BD4D0B> in the NSW Archaeology
    Online: Grey Literature Archive.

## Learn more
### Who cares about (alt)metrics?

Alternative metrics or "altmetrics" count the number of views, number of
downloads, social media "likes" and recommendations associated with a
dataset (or any resource). Because of their immediacy, altmetrics can be
an early indicator of the impact or reach of a dataset; long before
formal citation metrics can be assessed.

1.  Start by looking at the altmetrics for this [phylogenomics
    article](http://www.sciencemag.org/articleusage?gca=sci;346/6210/763 "phylogenomics article")
    published in *Science*. Note the usage statistics, including number
    and pattern of downloads, for this article since it was published in
    November 2014.
2.  Now click on the “donut” or the link to ‘See More Details’ to see
    the wealth of information available.
3.  Look also at the associated [data in
    Dryad](http://datadryad.org/resource/doi:10.5061/dryad.3c0f1) noting
    that the data has been assigned a DOI. Can you see how many times
    the data has been downloaded and the record viewed (scroll down to
    the bottom of the record)?

By way of comparison, as of early November 2018:

-   the same dataset had been cited once in Web of Science Data Citation
    Index
-   the article had been cited 690 times in [Web of
    Science](http://apps.webofknowledge.com/full_record.do?product=WOS&search_mode=GeneralSearch&qid=2&SID=E4hcr2sIg7gEPv5OcTf&page=1&doc=3 "Web of science - citation of Phylogenomics paper") (requires log in)

**Consider:** Do you think altmetrics for data have value in academic
settings?  Why, or why not?

## Challenge me
### Minting DOIs for research data

The ARDC DOI service enables research organisations to
assign Digital Object Identifiers (DOIs) to research datasets and
collections as well as well as associated software, workflows, models
and grey literature. The service is intended for use by publicly funded
Australian  research organisations and is available as a
machine-to-machine or manual service.

1.  Start by reading an overview of the [ARDC DOI
    service](https://ardc.edu.au/services/identifier/doi/ "DOI service")
    and perhaps the [ARDC Guide to DOI system and research data](https://ardc.edu.au/wp-content/uploads/2019/05/Digital_Object_Identifier_DOI_System_for_Research_Data.pdf) ARDC DOI service [technical
    documentation](https://documentation.ardc.edu.au/display/DOC/DOI+Service).
2.  Consider also the need for guidelines around when a DOI will be
    minted, by whom and how DOIs will be managed to ensure long term
    persistence. You might like to look at these examples of
    institutional guidelines for DOI minting:
    1.  [Australian Antarctic Division Data
        Policy](https://data.aad.gov.au/aadc/about/data_policy.cfm#Metadata "Australian Antarctic division data policy")
    2.  [Griffith University Digital Object Identifiers: Introduction
        and Management
        Guide](https://www2.griffith.edu.au/__data/assets/pdf_file/0039/198795/Griffith-University-DOI-guide_1.1-Rev.pdf "Griffith University DOI Guide")

### Want to know more about the ARCD DOI minting service for data, and now grey literature?

**Webinar: ARDC expanded DOI service: scope, requirements and FAQs**.

Watch the [recording](https://youtu.be/FZPbhHI-a_c "Recording") or go
through the
[slides](http://www.slideshare.net/AustralianNationalDataService/doi-service-expanded-from-webinar-11th-may-2016).

**Consider:** What do you think are the critical issues to ensure the
persistence of DOIs over a number of years?
