---
layout: thing
thing: 15
title: 'Data management plans'
description: |
    Some research institutions and research funders now require researchers
    to submit a Data Management Plan (DMP) for new projects. What should a
    DMP cover? Could you help with one?
overview:
 Getting started: What’s a DMP?
 Learn more: Why machine-actionable DMPs?
 Challenge me: Exploring DMP Tools
category: Let's talk data
---

[Find out about the work of the Australasian DMP Interest
Group](http://tiny.cc/DMP-IG)

## Getting started 
### An introduction to Data Management Plans

A Data Management Plan (DMP) documents how data will be managed, stored
and shared during and after a research project. Some research funders
are now requesting that researchers submit a DMP as part of their
project proposal.

1.  Start by scanning this short introduction to [Data Management
    Plans](https://www.ands.org.au/working-with-data/data-management/data-management-plans)
2.  Now browse through some public DMPs from either  the CDL or DataOne,
    and open up one or two of the DMPs to see the type of information
    they capture:

-   [California Digital
    Library](https://dmptool.org/public_plans "DMP tool - public DMP plans")
-   [DataOne](https://www.dataone.org/data-management-planning)

**Consider:** You will have noticed that DMPs can be very short, or
extremely long and complex. What do you think are the two or three
pieces of information essential to include in every DMP and why?

## Learn more
### Templates for Data Management Plans

Imagine if the information contained in a DMP could flow across other
systems automatically (e.g. to populate faculty profiles, monitor
grants, notify repositories of data in the pipeline) and reduce
administrative burdens. 

What if DMPs were part of active research workflows, and served to
connect researchers with tailored guidance and resources at appropriate
points over the course of a project?

Machine actionable DMPs will help make this possible.
*Machine-actionable* “refers to information that is structured in a
consistent way so that machines, or computers, can be programmed against
the structure” ([DDI
definition](https://www.ddialliance.org/taxonomy/term/198)).

1.  Read up on how the international community is re-thinking DMPs in
    the [White paper on machine-actionable Data Management
    Plans](http://riojournal.com/articles.php?id=13086). This White
    Paper is long, but incredibly rich - scroll down for lots of
    use-cases, interoperability, data discovery and more.
2.  Take a look at a European perspective on Australia's tools for creating and
    integrating DMPs in the blog post [DMP Inspiration Down Under](http://www.dcc.ac.uk/blog/dmp-inspiration-down-under), and see what lessons we can learn from Europe in [this Webinar](https://ardc.edu.au/resource/data-management-planning-lessons-for-europe-webinar-video/) from Sarah Jones
    of the Digital Curation Centre.


**Consider:** Do you think machine-actionable DMPs will make them more
valuable to researchers? Institutions? Funders?

## Challenge me 
### Data Management Plans for the Humanities

1.  First have a look at the [The DMPTool: A Brief Overview 90 sec
    video](https://www.youtube.com/watch?v=xT1by-p5jUw&feature=youtu.be "DMP overview video")
    to see what the DMPTool offers researchers and institutional data
    managers
2.  Then read [this
    blog](https://blog.dmptool.org/category/roadmap-project) about how
    the Digital Curation Centre UK (DCC) and University of California
    Curation Centre (UCCC) have joined forces to create a new tool,
    called DMPRoadmap.
3.  Next browse the DMPRoadmap [development
    wiki](https://github.com/DMPRoadmap/roadmap/wiki/Development-roadmap)
    on GitHub.

**Consider:** The DMPRoadmap project is aiming to enable DMP’s to be
active, dynamic, machine-readable and FAIR. Can you suggest additional
goals or further enhancements?

[Find out about the work of the Australasian DMP Interest
Group](http://tiny.cc/DMP-IG)
