---
layout: thing
thing: 19
title: 'Exploring APIs and Apps'
short_title: 'APIs & Apps'
description: |
    APIs and Apps are the engines behind making data usable. Find out what
    they are and how they make data accessible to us all. Get hands on to
    explore and use APIs relevant to research data including services
    offered by ANDS and the National Library of Australia.
overview:
 Getting started: try some Culture Collage and get some apps to become a citizen scientist
 Learn more: explore the API treasures of Trove
 Challenge me: play with some APIs for ANDS services
category: 'Hands on with data & tools'
---
## Getting started
### An introduction to APIs and Apps

Apps and APIs are tools which make data much more discoverable and
usable for all of us - not just researchers!  You can choose to explore
both APIs and Apps or just one.

**Option 1: How are APIs used with data?**

APIs are important for research data because they are used by developers
to cleverly make data more discoverable and re-usable eg the Google Maps
API is very widely used to record the exact location of a species, or
photograph and lets developers embed Google Maps on webpages.

1. Start by watching this easy, short (3.24 min) video, ‘[What is an
API?](https://www.youtube.com/watch?v=s7wmiS2mSXY)’

2. Metadata records often show at least 2 different APIs in action.
[Interview material from Western Sydney women's oral history project:
'From farms to freeways: Women's memories of Western
Sydney'](https://researchdata.ands.org.au/interview-material-western-western-sydney/561264/)
metadata record shows both:

-   Google Maps API for the area map (zoom in to see the exact location
    where the data was collected)
-   Views and Accesses API

3. Trove at the National Library of Australia uses APIs to showcase
National Library of Australia collections in amazing ways. Check out the
[Trove Applications
Galley](http://help.nla.gov.au/trove/building-with-trove/application-gallery "Trove")
to see some clever uses of Trove APIs. ****

**Just for fun**: Stay in the [Trove Applications
Galley](http://help.nla.gov.au/trove/building-with-trove/application-gallery "Trove")
to find out what was making news **today** in history?

- Click on *Culture Collage* then click on the *On this day* API icon !

**Option 2: Apps for researchers and citizen scientists (is that you?)**

Often several little APIs underpin a (software) App(lication)
(program). Data gatherers in the field use apps to make data collection
easier, more accurate and more rich. eg fill out data forms offline on
their smartphones and tablets, capture images, photos, videos and
sounds, track locations on maps (probably using the Google Map API), and
much more. They're flexible tools that can help researchers gather more
information and work faster.

Choose one or both of these links to explore:

-   Scroll down to the list of the [10 of the Best Apps for Gathering
    Data in the
    Field](https://zapier.com/learn/ultimate-guide-to-forms-and-surveys/best-data-collection-apps/).
    Check out uses and associated costs.
-   Scroll down to the list of [8 Apps That Turn Citizens into
    Scientists](http://www.scientificamerican.com/article/8-apps-that-turn-citizens-into-scientists/) -
    this is American but also has globally applicable apps.

**Consider:** most of us have used public transport apps and APIs -
think about the source of the data which enables real time transport
information to be presented to you via an easy to read App and/or API.

## Learn more
### Discover the treasures in Trove

Get hands on with APIs and Queries.  Trove is a free discovery service
provided by the National Library of Australia. It provides access to
millions of Australian resources including newspaper articles, images
and manuscripts. The Trove API enables people to create new
applications, tools  and  interfaces using the rich store of Trove data.

1. Start by browsing around the [Trove Application
Gallery](http://help.nla.gov.au/trove/building-with-trove/application-gallery)
for some of the creative ways people have used the Trove API. Be
inspired!

2. To see more of the power of one API, watch this [short
video](https://www.youtube.com/watch?v=GMkGlOYvz8I)(3:09
min). The screen is a bit fuzzy but you can get the idea of this innovative “use your
voice to query Trove” API.

**Share** your thoughts on how APIs could make data more exciting and
accessible for more people.

**If you have time to get hands on!**

3. Browse the
[introduction](http://help.nla.gov.au/trove/building-with-trove) to the
[Trove API](http://help.nla.gov.au/trove/building-with-trove/api).

4. Go the [Trove API Console](http://troveconsole.herokuapp.com/) and
click on some of the example searches provided. The results are in a
machine readable format but look closely and you can see the citation
details eg title, date, source, pagination

5. Try constructing your own API query to see what results you
get.  Note that: If you want to use them in your own code you'll need to
get an API key and add '&key=\[Your API key\]' to the url.

**Consider:** the success of your code query - how could you get
different results by varying the query?

## Challenge me
### Unleash the power of APIs

APIs and Apps are the transformation agents which make data and services
powerful and accessible. These two options give you a chance to see how
APIs can be applied to either data or services.

**Option 1**: **Hands-on API tutorials**
Are you new to APIs and want a hands-on introduction to commonly used
APIs, including Twitter and YouTube? Work through some or all of the [tutorial from freeCodeCamp](https://www.youtube.com/watch?v=GZvSYJDk-us) to get hands on learning about working with APIs.

**Consider:** how the APIs could be applied to a dataset to make it more reusable?

**Option 2: APIs for ANDS Services**
If your institution uses ANDS services, you might want to use one or
more of these APIs to enhance your services.

Explore one of these APIs to get a feel for what the API does and
whether it may be useful to your organisation:

-   [OAI-PMH
    Provider](https://documentation.ardc.edu.au/display/DOC/OAI-PMH+Provider "OAI"):
    use this API if your system is a harvester which is compatible with
    the OAI-PMH protocol.
-   [Research Activity Grants
    API](https://documentation.ardc.edu.au/display/DOC/Research+Activities+API "Grants API"):
    provides machine access to research activity information contributed
    to Research Data Australia such as grants and projects. A
    light-weight method to query the ANDS Registry for specific
    information about Research Activity.

**Option 3: Going National and International**

Explore these APIs from other national and international organisations:

National organisations:

-   [Australian Urban Research Infrastructure
    Network](https://aurin.org.au/aurin-apis/ "AURIN")
-   [Atlas of Living
    Australia](https://api.ala.org.au/ "Atlas of living Australia")
-   [Bioplatforms
    Australia](https://data.bioplatforms.com/organization/pages/bioplatforms-australia/api-access "Bioplatforms Australia")
-   [National Museum
    Australia](http://www.nma.gov.au/about/our-collection/our-apis "National Museum of Australia")

International organisations:

-   [Re3data.org](https://www.re3data.org/search?query=api "Re3data")
